@@ -2,20 +2,22 @@
 import XCTest
 
 final class {{ name }}CellsTests: XCTestCase {
-{% for p in properties %}
+    {% for p in properties %}
     private var {{ p.name }}Cell: {{ model_name }}{{ p.name_title }}Cell!
-{% endfor %}
+    {% endfor %}
 
     override func setUp() {
         super.setUp()
-    {% for p in properties %}
+        {% for p in properties %}
         {{ p.name }}Cell = {{ model_name }}{{ p.name_title }}Cell.loadFromNib()
-    {% endfor %}
+        {% endfor %}
     }
 
     func test_ibOutlets() {
-    {% for p in properties %}
-        XCTAssertNotNil({{ p.name }}Cell.{{ p.name }}Label)
-    {% endfor %}
+        {% for p in properties %}
+        // {{ p.name_title }} cell
+        XCTAssertNotNil({{ p.name }}Cell)
+        XCTAssertNotNil({{ p.name }}Cell.{{ p.name }}Label){{ '\n' if not loop.last }}
+        {% endfor %}
     }
 }
